# How to Use Your Parameter Struct
**Description**: This tutorial will familiarize you with how you can use the autogenerated parameter structs in your nodes.
**Tutorial Level**: INTERMEDIATE

## Generated files
When creating params files as described in [How to write your first .params file](HowToWriteYourFirstParamsFile.md), you will end up with the following two files:
- *'include/rosparam_tutorials/TutorialParameters.h'*
- *'include/rosparam_tutorials/TutorialConfig.h'*

The '<name>Parameters.h' file will hold a struct called `<name>Parameters`.  
The '<name>Config.h' file will hold the normal dynamic_reconfigure Config struct.

For your code it is enough to include the \*Parameters.h file, e.g.

```cpp
#include "rosparam_tutorials/TutorialParameters.h"
```

You can now add an instance of the parameter struct to your class:

```cpp
rosparam_tutorials::TutorialParameters params_;
```

## Initializing the struct.
When initializing your node, the params struct must be initialized with a private NodeHandle.

The call to `fromParamServer()` will take care of getting all parameter values from the parameter server, checking their type, and checking that a default value is set, if you haven't provided one on your own. When min and max values are specified, these bounds will be checked as well.

```cpp
MyNodeClass::MyNodeClass()
  : params_{ros::NodeHandle("~")}
{
  params_.fromParamServer();
}
```

If you do not use a class (which you should do though in my opinion), you can create it like so:
```cpp
rosparam_tutorials::TutorialParameters params_{ros::NodeHandle("~")}
params_.fromParamServer();
```
Note: If you have set the logger level for your node to debug, you will get information on which values have been retrieved.  
Note: If you use nodelets, you have to use the `getPrivateNodeHandle()` function instead.

## Using dynamic_reconfigure
Your dynamic_reconfigure callback can now look as simple as:
```cpp
void reconfigureRequest(TutorialConfig& config, uint32_t level) {
    params_.fromConfig(config);
}
```
This will update all values that were specified as configurable. At the same time, it assures that all dynamic_reconfigure parameters live in the same namespace as those on the parameter server to avoid problems with redundant parameters.

You can find a running version of this example code in the [rosparam_handler_tutorial](https://github.com/cbandera/rosparam_handler_tutorial)-Repository